<?php

	$link = mysql_connect( /* Zugangs-Daten des Servers */);
	$database = /* "Datenbankname" */;
	mysql_select_db($database, $link);

		$sqla = "UPDATE p_erg SET sa1_a = '" . $_GET[sa1_a] . "', sa1_l = '" . $_GET[sa1_l] . "', sa2_a = '" . $_GET[sa2_a] . "', sa2_l = '" . $_GET[sa2_l] . "', sa3_a = '" . $_GET[sa3_a] . "', sa3_l = '" . $_GET[sa3_l] . "', sa4_a = '" . $_GET[sa4_a] . "', sa4_l = '" . $_GET[sa4_l] . "', Datum=NOW() WHERE id = '" . $_GET[myid] . "' AND ueberl='" . $_GET[ueberlister] . "'";
		$ergebnisa = mysql_query($sqla, $link);

	
?>