<?php

	$link = mysql_connect( /* Zugangs-Daten des Servers */);
	$database = /* "Datenbankname" */;
	mysql_select_db($database, $link);
	
	$paff = explode("-", $_GET[ausschl]);
	
	for ($i=0; $i<9; $i++) {
		if ($paff[$i] != "") {
			if ($i < 1) {
				$bdg .= "AND ano != '" . $paff[$i] . "' ";
			} else {
				$bdg .= "AND ano != '" . $paff[$i] . "' ";
			}
		}
	}
	
	$sql = "SELECT MIN(realis) as wt FROM p_ano_ff WHERE txno = '" . $_GET[wetx] . "' " . $bdg . " LIMIT 1";
	$ergebnis = mysql_query($sql, $link);
	
	$infrage = array();
	$abgleic = array();
	
	while ($row = mysql_fetch_array($ergebnis)) {
	
		$sqla = "SELECT ano FROM p_ano_ff WHERE realis = '" . $row[wt] . "' AND txno = '" . $_GET[wetx] . "' " . $bdg . "";
		$ergebnisa = mysql_query($sqla, $link);
			
			while ($rowa = mysql_fetch_array($ergebnisa)) {
				array_push($infrage, $rowa[ano]);
			}
			
		$sqlb = "SELECT SUM(realis) as rflge, ano FROM p_ano_ff GROUP BY ano ORDER BY rflge";
		$ergebnisb = mysql_query($sqlb, $link);

		$schluss = "ja";
			
			while ($rowb = mysql_fetch_array($ergebnisb)) {
				if ($schluss == "ja") {
					$minzahl = $rowb[rflge];
				}
				if ($minzahl == $rowb[rflge]) {
					$zeil++;
					for ($i=0; $i<(count($infrage)); $i++) {
						if ($rowb[ano] == $infrage[$i]) {
							array_push($abgleic, $rowb[ano]);
							$schluss = "nein";
						}
					}
				}
			}
			
		$zf = rand(0,((count($abgleic)) - 1));
		$rzf = floor($zf);
		
		echo "&ausgang=" . $abgleic[$rzf] . "&gefd=1&";
	}
	
	if ($_GET[wetx] < 2 AND $_GET[wetx] > 0) {
		$meineip = $_SERVER["REMOTE_ADDR"];
		$sql = "INSERT INTO p_erg (ip_adr, art, durchg, ueberl, aufloes, schirm, wiealt, syst, f0_g0_d0_b0) VALUES ('" . $meineip . "', '" . $_GET[art] . "', '" . $_GET[durchg] . "', '" . $_GET[ueberlister] . "', '" . $_GET[xmass] . "x" . $_GET[ymass] . "', '" . $_GET[schirm] . "', '" . $_GET[wiealt] . "', '" . $_GET[systemis] . "', '0.000')";
		$ergebnis = mysql_query($sql, $link);
		echo "nutzid=" . mysql_insert_id() . "&";
	}

	
	
	
?>