<?php

	$link = mysql_connect( /* Zugangs-Daten des Servers */);
	$database = /* "Datenbankname" */;
	mysql_select_db($database, $link);

		$sqla = "UPDATE p_erg SET t_" . $_GET[wetex] . "='" . $_GET[zt] . "', " . $_GET[wohin] . "='" . $_GET[zt] . "', feh_" . $_GET[wetex] . "='" . ($_GET[fhl] - 2) . "', Datum=NOW() WHERE id = '" . $_GET[myid] . "' AND ueberl='" . $_GET[ueberlister] . "'";
		$ergebnisa = mysql_query($sqla, $link);

		$sqla = "UPDATE p_ano_ff SET wert=wert+1, realis=realis+1 WHERE ano = '" . $_GET[wohin] . "' AND txno = '" . $_GET[wetex] . "'";
		$ergebnisa = mysql_query($sqla, $link);
	
	
?>